local P4AddictedToWeight = {}
local self = P4AddictedToWeight
self.isDisplayed = false
self.currentWeight = nil
self.currentStatus = nil
self.currentItemSize = nil
self.indicator = nil

self.OnCreatePlayer = function(index, player)
	self.currentItemSize = -1
	self.indicator = P4WeightIndicator:new(player, 0, 0, 0, 0, "P4WeightIndicator")
	self.indicator:initialise()
end
Events.OnCreatePlayer.Add(self.OnCreatePlayer)

self.OnPlayerUpdate = function(player)
	local items = player:getInventory():getItems()
	local itemSize = items:size()
	if self.currentItemSize ~= itemSize then
		local sizeDiff = itemSize - self.currentItemSize
		self.currentItemSize = itemSize
		if self.isDisplayed and sizeDiff > 0 then
			-- no needs to check digital watch
		elseif not self.isDisplayed and sizeDiff < 0 then
			-- no needs to check digital watch
		elseif self.hasDigitalWatch(items) then
			self.setDisplayOn()
		else
			self.setDisplayOff()
		end
	end
	if self.isDisplayed then
		local nutrition = player:getNutrition()
		local weight = math.floor(nutrition:getWeight() * 10) / 10
		if self.currentWeight ~= weight then
			self.currentWeight = weight
			local digit1 = math.floor(weight / 10)
			local digit2 = math.floor(weight) - (digit1 * 10)
			local digit3 = math.floor(weight * 10) - (math.floor(weight) * 10)
			self.indicator:setDigit1(digit1)
			self.indicator:setDigit2(digit2)
			self.indicator:setWTexture(digit3)
		end
		local stauts = "n"
		if nutrition:isIncWeightLot() then
			status = "l"
		elseif nutrition:isIncWeight() then
			status = "i"
		elseif nutrition:isDecWeight() then
			status = "d"
		end
		if self.currentStatus ~= status then
			self.currentStatus = status
			self.indicator:setSTexture(status)
		end
	end
end
Events.OnPlayerUpdate.Add(self.OnPlayerUpdate)

self.hasDigitalWatch = function(items)
	for i = 0, items:size() - 1 do
		local item = items:get(i)
		local type = item:getFullType()
		if string.match(type, "Base.WristWatch_Left_Digital") or string.match(type, "Base.WristWatch_Right_Digital") then
			return true
		end
	end
	return false
end

self.setDisplayOn = function()
	self.isDisplayed = true
	self.indicator:setVisible(true)
end

self.setDisplayOff = function()
	self.isDisplayed = false
	self.indicator:setVisible(false)
end
